#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-GQINB4Yj4HZ13mj5L8rNRP
key:                  asn1-types-0.3.4-GQINB4Yj4HZ13mj5L8rNRP
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  2fb963f1548138c227a2bb9eef6746fd
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-types
hs-libraries:         HSasn1-types-0.3.4-GQINB4Yj4HZ13mj5L8rNRP
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hourglass-0.2.12-9c5NbwYjSlUL3g0VVzpM1U
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

